==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Pluginul % 1 nu este compatibil cu sistemul.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Setări Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Oprește</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Pornește</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Setări Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectat</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectare...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Oprit</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Adăugare aspect  tastatură</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data și ora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Format 12-ore</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Format 24-ore</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Configurări pentru timp</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Activați rețeaua</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Dezactivați conexiunea la rețea</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configurări de rețea</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Sunteți doriți să goliți %1 articole?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ștergeți</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Această acţiune nu a putut fi restaurată</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispozitiv necunoscut</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volum necunoscut</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Demontați-le pe toate</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lansator</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mod aspectuos</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mod eficient</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Sus</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Jos</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Stânga</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dreapta</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Păstrați docul afișat</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Păstrați docul ascuns</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ascundere inteligentă</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locație</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stare</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Extensii</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vizualizare Multitask</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Detaşaţi</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Dezactivați conexiunea prin cablu</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activați conexiunea prin cablu</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Dezactivați conexiunea fără fir</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activați conexiunea fără fir</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Dezactivați conexiunea la rețea</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activați rețeaua</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configurări de rețea</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Dispozitiv Dezactivat</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Conexiune fără fir: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Conexiune prin cablu: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neconectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectat dar fară acces Internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cablu Reţea Deconectat</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rețea fără fir</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rețea conectată</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Reţea</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rețea conectată</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rețea Cablu %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>La bord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Setări pentru administrare de energie</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacitate %1, %2 Min rămase</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacitate %1, %2 Ore %3 Min rămase</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Încărcare %1, %2 Min până la plin</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Încărcare %1, %2 Ore %3 Min rămase până la plin</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Încărcat</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capactitate %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Se încarcă %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capactitate %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacitate %1, complet încărcat</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Arată desktop-ul</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Detaşaţi</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernare</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocare</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Ieșire</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Schimbă conturile</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Setări pentru administrare de energie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Repornire</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispozitiv</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Activați sunetul</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Setări Sunet</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Sunet</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Gunoi</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Coș de reciclare - %1 fișier</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Coș de reciclare - %1 fișiere</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Gol</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Platou de sistem</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rețea fără fir</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rețea fără fir %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Pluginul % 1 nu este compatibil cu sistemul.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Oprește</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Pornește</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Elimină</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Setări Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Oprește</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Pornește</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Setări Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectat</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectare...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Oprit</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Adăugare aspect  tastatură</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data și ora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Format 12-ore</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Format 24-ore</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Configurări pentru timp</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Sunteți doriți să goliți %1 articole?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ștergeți</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Această acţiune nu a putut fi restaurată</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispozitiv necunoscut</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volum necunoscut</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Demontați-le pe toate</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lansator</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mod aspectuos</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mod eficient</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Sus</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Jos</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Stânga</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dreapta</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Păstrați docul afișat</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Păstrați docul ascuns</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ascundere inteligentă</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locație</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stare</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Dimensiune</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Afișaje multiple</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Mod fashion</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Mod eficient</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Sus</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Jos</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Stânga</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dreapta</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locație</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Păstraţi ascuns</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ascundere inteligentă</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stare</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Mic</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Mare</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vizualizare Multitask</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Detaşaţi</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>La bord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Setări pentru administrare de energie</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacitate %1, %2 Min rămase</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacitate %1, %2 Ore %3 Min rămase</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Încărcare %1, %2 Min până la plin</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Încărcare %1, %2 Ore %3 Min rămase până la plin</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capactitate %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Se încarcă %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capactitate %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacitate %1, complet încărcat</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Arată desktop-ul</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Detaşaţi</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernare</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocare</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Ieșire</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Schimbă conturile</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Setări pentru administrare de energie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Repornire</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispozitiv</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Activați sunetul</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Setări Sunet</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Sunet</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Gunoi</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Coș de reciclare - %1 fișier</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Coș de reciclare - %1 fișiere</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>La gunoi</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Gol</translation>
    </message>
</context>
</TS>
